Driver for the SX1280 RF Transceiver

Dependents:   SX1280PingPong RangignMaster RangingSlave MSNV2-Terminal_V1-6 ... more

Revision:
5:b4014e8b7be1
Parent:
4:abf14b677777
Child:
7:88669efa3779
diff -r abf14b677777 -r b4014e8b7be1 sx1280.h
--- a/sx1280.h	Thu May 11 15:41:52 2017 +0000
+++ b/sx1280.h	Mon May 22 11:23:03 2017 +0000
@@ -1290,17 +1290,17 @@
      * driver, a second optional argument must be provided evaluating as true
      * boolean
      *
      * \param [in]  isLazy        If true, the packet type returned is the last
      *                            saved in the driver
      *                            If false, the packet type is obtained from
      *                            the chip
      *                            Default: false
      *
      * \retval      packetType    [PACKET_TYPE_GENERIC, PACKET_TYPE_LR24,
      *                             PACKET_TYPE_RANGING, PACKET_TYPE_FLRC,
      *                             PACKET_TYPE_BLE, PACKET_TYPE_NONE]
      */
-    RadioPacketTypes_t GetPacketType( bool isLazy = false );
+    RadioPacketTypes_t GetPacketType( bool returnLocalCopy = false );
 
     /*!
      * \brief Sets the RF frequency
@@ -1290,17 +1290,17 @@
      * boolean
      *
-     * \param [in]  isLazy        If true, the packet type returned is the last
-     *                            saved in the driver
-     *                            If false, the packet type is obtained from
-     *                            the chip
-     *                            Default: false
+     * \param [in]  returnLocalCopy If true, the packet type returned is the last
+     *                              saved in the driver
+     *                              If false, the packet type is obtained from
+     *                              the chip
+     *                              Default: false
      *
      * \retval      packetType    [PACKET_TYPE_GENERIC, PACKET_TYPE_LR24,